@@ -57,6 +57,9 @@ LAUNCH_STAGE_ANNOTATION = RUN_GROUP + '/launch-stage'
 BINAUTHZ_POLICY_ANNOTATION = RUN_GROUP + '/binary-authorization'
 BINAUTHZ_BREAKGLASS_ANNOTATION = RUN_GROUP + '/binary-authorization-breakglass'
 
+EXECUTION_ENVIRONMENT_ANNOTATION = RUN_GROUP + '/execution-environment'
+CUSTOM_AUDIENCES_ANNOTATION = RUN_GROUP + '/custom-audiences'
+
 
 def Meta(m):
   """Metadta class from messages module."""
@@ -479,7 +482,7 @@ class LazyListWrapper(collections_abc.MutableSequence):
     self._l.insert(i, v)
 
 
-class ListAsReadOnlyDictionaryWrapper(collections.Mapping):
+class ListAsReadOnlyDictionaryWrapper(collections_abc.Mapping):
   """Wraps repeated messages field with name in a dict-like object.
 
   This class is a simplified version of ListAsDictionaryWrapper for when there
