@@ -323,10 +323,9 @@ TARGET_SSL_PROXY_ARG = compute_flags.ResourceArgument(
     resource_name='ssl proxy',
     global_collection='compute.targetSslProxies',
     short_help='Target SSL proxy that receives the traffic.',
-    detailed_help=('Target SSL proxy that receives the traffic. '
-                   'Acceptable values for `--ports` flag are: '
-                   '25, 43, 110, 143, 195, 443, 465, 587, '
-                   '700, 993, 995, 1883, 5222.'))
+    detailed_help=textwrap.dedent("""\
+      Target SSL proxy that receives the traffic. For the acceptable ports, see [Port specifications](https://cloud.google.com/load-balancing/docs/forwarding-rule-concepts#port_specifications).
+      """))
 
 TARGET_TCP_PROXY_ARG = compute_flags.ResourceArgument(
     name='--target-tcp-proxy',
@@ -334,10 +333,9 @@ TARGET_TCP_PROXY_ARG = compute_flags.ResourceArgument(
     resource_name='tcp proxy',
     global_collection='compute.targetTcpProxies',
     short_help='Target TCP proxy that receives the traffic.',
-    detailed_help=('Target TCP proxy that receives the traffic. '
-                   'Acceptable values for --ports flag are: '
-                   '25, 43, 110, 143, 195, 443, 465, 587, '
-                   '700, 993, 995, 1883, 5222.'))
+    detailed_help=textwrap.dedent("""\
+      Target TCP proxy that receives the traffic. For the acceptable ports, see [Port specifications](https://cloud.google.com/load-balancing/docs/forwarding-rule-concepts#port_specifications).
+      """))
 
 TARGET_VPN_GATEWAY_ARG = compute_flags.ResourceArgument(
     name='--target-vpn-gateway',
@@ -357,7 +355,7 @@ def AddressArgHelp(include_l7_internal_load_balancing, include_gfe3,
                    include_l7_rxlb):
   """Build the help text for the address argument."""
 
-  lb_schemes = '(EXTERNAL, INTERNAL, INTERNAL_MANAGED'
+  lb_schemes = '(EXTERNAL, INTERNAL, INTERNAL_SELF_MANAGED'
   if include_l7_internal_load_balancing:
     lb_schemes += ', INTERNAL_MANAGED'
   if include_gfe3 or include_l7_rxlb:
@@ -380,7 +378,7 @@ def AddressArgHelp(include_l7_internal_load_balancing, include_gfe3,
     - global/addresses/address-1
     - address-1
 
-    The load-balancing-scheme (%s) and the forwarding rule's target determine
+    The load-balancing-scheme %s and the forwarding rule's target determine
     the type of IP address that you can use. The address type must be external
     for load-balancing-scheme EXTERNAL or EXTERNAL_MANAGED, and for the other
     load-balancing-schemes the address must be internal. For detailed
