@@ -41,6 +41,7 @@ PURPOSE_MAP = {
     'encryption': PURPOSE_ENUM.ENCRYPT_DECRYPT,
     'asymmetric-signing': PURPOSE_ENUM.ASYMMETRIC_SIGN,
     'asymmetric-encryption': PURPOSE_ENUM.ASYMMETRIC_DECRYPT,
+    'mac': PURPOSE_ENUM.MAC,
 }
 
 PROTECTION_LEVEL_ENUM = (
@@ -72,11 +73,15 @@ VALID_ALGORITHMS_MAP = {
         'rsa-sign-pkcs1-4096-sha512',
     ],
     PURPOSE_ENUM.ASYMMETRIC_DECRYPT: [
+        'rsa-decrypt-oaep-2048-sha1',
         'rsa-decrypt-oaep-2048-sha256',
+        'rsa-decrypt-oaep-3072-sha1',
         'rsa-decrypt-oaep-3072-sha256',
+        'rsa-decrypt-oaep-4096-sha1',
         'rsa-decrypt-oaep-4096-sha256',
         'rsa-decrypt-oaep-4096-sha512',
     ],
+    PURPOSE_ENUM.MAC: ['hmac-sha256',]
 }
 
 # Derive available algorithms from VALID_ALGORITHMS_MAP.
