@@ -18,6 +18,7 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import unicode_literals
 
+from googlecloudsdk.calliope import arg_parsers
 from googlecloudsdk.calliope import base
 
 
@@ -73,6 +74,7 @@ def AddPurposeArgToParser(parser):
   parser.add_argument(
       "--purpose",
       metavar="PURPOSE",
+      choices=["GCE_FIREWALL"],
       help=("Purpose specifier of the TagKey that can only be set on creation. "
             "Specifying this field adds additional validation from the policy "
             "system that corresponds to the purpose."))
@@ -86,7 +88,10 @@ def AddPurposeDataArgToParser(parser):
   """
   parser.add_argument(
       "--purpose-data",
-      metavar="PURPOSE_DATA",
+      type=arg_parsers.ArgDict(
+          spec={"network": str},
+          max_length=1,
+      ),
       help=("Purpose data of the TagKey that can only be set on creation. "
             "This data is validated by the policy system that corresponds"
             " to the purpose."))
@@ -125,9 +130,7 @@ def AddForceArgToParser(parser):
     parser: ArgumentInterceptor, An argparse parser.
   """
   parser.add_argument(
-      "--force",
-      action="store_true",
-      help=("Force argument to bypass checks."))
+      "--force", action="store_true", help=("Force argument to bypass checks."))
 
 
 def AddPolicyFileArgToParser(parser):
@@ -147,7 +150,7 @@ def AddPolicyFileArgToParser(parser):
 
 
 def AddTagValueArgToParser(parser):
-  """Adds the TagValue arugument to the parser.
+  """Adds the TagValue argument to the parser.
 
   Args:
     parser: ArgumentInterceptor, An argparse parser.
@@ -163,3 +166,13 @@ def AddTagValueArgToParser(parser):
             "with an alphanumeric character ([a-z0-9A-Z]) with dashes (-), "
             "underscores (_), dots (.), and alphanumerics between."))
 
+
+def AddLocationArgToParser(parser, message):
+  """Adds argument for the location.
+
+  Args:
+    parser: ArgumentInterceptor, An argparse parser.
+    message: String, help text for flag.
+  """
+  parser.add_argument(
+      "--location", metavar="LOCATION", required=False, help=message)
