@@ -1074,7 +1074,7 @@ class ServerlessOperations(object):
       tracker.StartStage(stages.UPLOAD_SOURCE)
       tracker.UpdateHeaderMessage('Uploading sources.')
       build_messages = cloudbuild_util.GetMessagesModule()
-      build_config = submit_util.CreateBuildConfigAlpha(
+      build_config = submit_util.CreateBuildConfig(
           build_image,
           False,
           build_messages,
@@ -1089,8 +1089,6 @@ class ServerlessOperations(object):
           None,
           None,
           None,
-          None,
-          None,
           build_pack,
           hide_logs=True)
       tracker.CompleteStage(stages.UPLOAD_SOURCE)
