@@ -168,11 +168,13 @@ def AddPromptForPassword(parser):
 
 
 def AddType(parser):
-  parser.add_argument('--type', help='Cloud SQL user\'s type. It determines '
-                      'the method to authenticate the user during login. '
-                      'See the list of user types at '
-                      'https://cloud.google.com/sql/docs/postgres/admin-api/'
-                      'rest/v1beta4/SqlUserType')
+  parser.add_argument(
+      '--type',
+      help='Cloud SQL user\'s type. It determines '
+      'the method to authenticate the user during login. '
+      'See the list of user types at '
+      'https://cloud.google.com/sql/docs/postgres/admin-api/'
+      'rest/v1beta4/SqlUserType')
 
 
 # Instance create and patch flags
@@ -301,7 +303,12 @@ def AddDatabaseFlags(parser, update=False):
       help=help_)
 
 
-def AddDatabaseVersion(parser, restrict_choices=True, hidden=False):
+def AddDatabaseVersion(parser,
+                       restrict_choices=True,
+                       hidden=False,
+                       support_default_version=True,
+                       expose_all_versions=True,
+                       expose_mvs_versions=False):
   """Adds `--database-version` to the parser with choices restricted or not."""
   # Section for engine-specific content.
   # This section is auto-generated by //cloud/storage_fe/sql/sync_engines.
@@ -315,6 +322,7 @@ def AddDatabaseVersion(parser, restrict_choices=True, hidden=False):
       'POSTGRES_11',
       'POSTGRES_12',
       'POSTGRES_13',
+      'POSTGRES_14',
       'SQLSERVER_2017_EXPRESS',
       'SQLSERVER_2017_WEB',
       'SQLSERVER_2017_STANDARD',
@@ -325,15 +333,31 @@ def AddDatabaseVersion(parser, restrict_choices=True, hidden=False):
       'SQLSERVER_2019_ENTERPRISE',
   ]
   # End of engine-specific content.
+
+  final_choices = []
+  if expose_all_versions:
+    final_choices.extend(choices)
+
+  mvs_choices = [
+      'MYSQL_8_0_18',
+      'MYSQL_8_0_26',
+  ]
+
+  if expose_mvs_versions:
+    final_choices.extend(mvs_choices)
+
+  help_text_unspecified_part = 'the API defaults are used.' if support_default_version else 'no changes occur.'
   help_text = (
-      'The database engine type and versions. If left unspecified, the API '
-      'defaults are used. See the list of database versions at '
+      'The database engine type and versions. If left unspecified, ' +
+      help_text_unspecified_part + ' See the list of database versions at ' +
       'https://cloud.google.com/sql/docs/mysql/admin-api/rest/v1beta4/SqlDatabaseVersion'
   )
+
   parser.add_argument(
       '--database-version',
       required=False,
-      choices=_MajorVersionMatchList(choices) if restrict_choices else None,
+      choices=_MajorVersionMatchList(final_choices)
+      if restrict_choices else None,
       help=help_text,
       hidden=hidden)
 
@@ -512,21 +536,22 @@ def AddMaintenanceWindowHour(parser):
 def AddDenyMaintenancePeriodStartDate(parser):
   parser.add_argument(
       '--deny-maintenance-period-start-date',
-      help='''Date when the deny maintenance period begins,
-       that is ``2020-11-01".''')
+      help='Date when the deny maintenance period begins, that is ``2020-11-01\'\'.'
+      )
 
 
 def AddDenyMaintenancePeriodEndDate(parser):
   parser.add_argument(
       '--deny-maintenance-period-end-date',
-      help='Date when the deny maintenance period ends, that is ``2021-01-10".')
+      help='Date when the deny maintenance period ends, that is ``2021-01-10\'\'.'
+  )
 
 
 def AddDenyMaintenancePeriodTime(parser):
   parser.add_argument(
       '--deny-maintenance-period-time',
-      help='''Time when the deny maintenance period starts or ends,
-       that is ``05:00:00".''')
+      help='Time when the deny maintenance period starts or ends, that is ``05:00:00\'\'.'
+  )
 
 
 def AddInsightsConfigQueryInsightsEnabled(parser, show_negated_in_help=False):
@@ -599,12 +624,18 @@ def AddAllocatedIpRangeName(parser):
   parser.add_argument(
       '--allocated-ip-range-name',
       required=False,
-      help=(
-          'The name of the IP range allocated for a Cloud SQL instance with '
-          'private network connectivity. For example: '
-          '\'google-managed-services-default\'. If set, the instance IP is '
-          'created in the allocated range represented by this name.'
-          ))
+      help=('The name of the IP range allocated for a Cloud SQL instance with '
+            'private network connectivity. For example: '
+            '\'google-managed-services-default\'. If set, the instance IP is '
+            'created in the allocated range represented by this name.'))
+
+
+def AddMaintenanceVersion(parser):
+  """Adds the `--maintenance-version` flag to the parser."""
+  parser.add_argument(
+      '--maintenance-version',
+      required=False,
+      help=('The current maintenance version of the instance.'))
 
 
 def AddSqlServerAuditBucketPath(parser):
@@ -613,11 +644,9 @@ def AddSqlServerAuditBucketPath(parser):
       '--audit-bucket-path',
       required=False,
       hidden=True,
-      help=(
-          'Path in Google Cloud Storage to upload generated audit files. '
-          'The URI is in the form gs://bucketName/folderName. '
-          'Only available for SQL Server instances.'
-          ))
+      help=('Path in Google Cloud Storage to upload generated audit files. '
+            'The URI is in the form gs://bucketName/folderName. '
+            'Only available for SQL Server instances.'))
 
 
 def AddReplication(parser):
@@ -692,9 +721,11 @@ def AddZonesPrimarySecondary(parser, help_text):
 
   zone_group = parser.add_group(required=False)
   zone_group.add_argument('--zone', required=False, help=help_text)
-  zone_group.add_argument('--secondary-zone', required=False,
-                          help=('Preferred secondary Compute Engine zone '
-                                '(e.g. us-central1-a, us-central1-b, etc.).'))
+  zone_group.add_argument(
+      '--secondary-zone',
+      required=False,
+      help=('Preferred secondary Compute Engine zone '
+            '(e.g. us-central1-a, us-central1-b, etc.).'))
 
 
 def AddRegion(parser):
@@ -767,8 +798,7 @@ def AddOffloadArgument(parser):
       help=(
           'Offload an export to a temporary instance. Doing so reduces strain '
           'on source instances and allows other operations to be performed '
-          'while the export is in progress.'
-      ))
+          'while the export is in progress.'))
 
 
 def AddQuoteArgument(parser):
@@ -962,7 +992,7 @@ def AddBackupRunId(parser):
       'id',
       type=arg_parsers.BoundedInt(lower_bound=1, unlimited=True),
       help='The ID of the backup run. You can find the ID by running '
-            '$ gcloud sql backups list -i {instance}.')
+      '$ gcloud sql backups list -i {instance}.')
 
 
 def AddPasswordPolicyMinLength(parser):
@@ -1195,7 +1225,6 @@ USERS_FORMAT_BETA = """
   )
 """
 
-
 USERS_FORMAT_ALPHA = USERS_FORMAT_BETA
 
 
@@ -1207,6 +1236,5 @@ def AddActiveDirectoryDomain(parser):
   """
   help_text = (
       'Managed Service for Microsoft Active Directory domain this instance is '
-      'joined to. Only available for SQL Server instances.'
-  )
+      'joined to. Only available for SQL Server instances.')
   parser.add_argument('--active-directory-domain', help=help_text)
