@@ -21,15 +21,14 @@ from __future__ import unicode_literals
 import base64
 import collections
 import enum
-import functools
 import hashlib
 import re
-import sys
 
 from googlecloudsdk.command_lib.storage import errors
 from googlecloudsdk.command_lib.storage import hash_util
 from googlecloudsdk.core import properties
 from googlecloudsdk.core import yaml
+from googlecloudsdk.core.cache import function_result_cache
 
 
 _CMEK_REGEX = re.compile('projects/([^/]+)/'
@@ -115,17 +114,7 @@ def parse_key(raw_key):
   return EncryptionKey(key=raw_key, sha256=sha256, type=key_type)
 
 
-def _lru_cache(function):
-  """Wraps functools.lru_cache, so it's not referenced at import in Python 2."""
-  if sys.version_info.major >= 3:
-    # Use size one since the function this wraps returns the contents of a
-    # single file.
-    return functools.lru_cache(maxsize=1)(function)
-  else:
-    return function
-
-
-@_lru_cache
+@function_result_cache.lru(maxsize=1)
 def _read_key_store_file():
   key_store_path = properties.VALUES.storage.key_store_path.Get()
   if not key_store_path:
